<?php
/*
Plugin Name: 123 Rewrite Error
Plugin URI: http://schnurpsel.de/?p=590
Description: Verhindert die unnötige Behandlung von fehlerhaften Requests durch WP.
Author: Ingo Henze
Version: 0.10
Author URI: http://putzlowitsch.de/
*/

function plw123rwe_activate() {
	global $wp_rewrite;
	$wp_rewrite->flush_rules();
}
register_activation_hook( __FILE__, 'plw123rwe_activate' );

function plw123rwe_deactivate() {
	global $wp_rewrite;
	remove_filter( 'mod_rewrite_rules', 'plw123rwe_mod_rewrite_rules', 66 );
	$wp_rewrite->flush_rules();
}
register_deactivation_hook( __FILE__, 'plw123rwe_deactivate' );

function plw123rwe_mod_rewrite_rules( $rules ) {
	global $wp_rewrite;
	
	$new_conditions = array();
	// Ist in der Permalink-Struktur eine Extension (z.B. .html) angegeben?
	if( preg_match( "~\\.([^\\.]+)\$~", $wp_rewrite->permalink_structure, $matches ) ) {
		$new_conditions[] = "RewriteCond %{REQUEST_URI}\t!\\.[^\\.]+\$ [OR]";
		$new_conditions[] = "RewriteCond %{REQUEST_URI}\t.{$matches[1]}\$  [OR]";  // nur Extension
		$new_conditions[] = "RewriteCond %{REQUEST_URI}\t.{$matches[1]}/[^\\.]+$";  // Extension mit Erweiterung (z.B. track_back)
	}
	else
		$new_conditions[] = "RewriteCond %{REQUEST_URI}\t!\\.[^\\.]+\$";
		
	// letzte Regel (RewriteRule) finden
	$rules_array = @explode( "\n", $rules );
	$temp_array = array();
	$rule_found = false;
	do {
		$line = array_pop( $rules_array );
		array_unshift( $temp_array, $line );
		if( null != $line ) {
			if( 0 === stripos( trim( $line ), 'rewriterule' ) )
				$rule_found = true;
		}
	}
	while( !$rule_found && count( $rules_array ) );

	// Regel gefunden, dann eigene Bedingungen hinzufügen
	if( $rule_found )
		$rules_array = array_merge( $rules_array, $new_conditions ); 
	
	// Temporär entfernte Zeilen wieder hinzufügen
	$rules_array = array_merge( $rules_array, $temp_array );
	
	$rules = implode( "\n", $rules_array );

  return $rules;
}
add_filter( 'mod_rewrite_rules', 'plw123rwe_mod_rewrite_rules', 66 );

?>